==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_fil.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fil" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Lumikha ng spreadsheet</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Lumikha ng isang bagong spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>I-align ang bottom</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Ihanay sa ibaba ang mga contents ng mga napiling cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Ihanay sa gitna</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Gitnang hanay ang mga contents ng mga napiling cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Ihanay sa kaliwa</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Kaliwang hanay ang mga contents ng mga napiling cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Ihanay sa kanan</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Right-align ang mga contents ng mga napiling cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Ihanay ang taas</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Top-align ang mga contents ng mga napiing cell</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Patayong center-align</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>I-export ang spreadsheet</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>I-export ang spreadsheet sa CSV file</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>I-import ang spreadsheet</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>I-import ang CSV file sa spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Pagsamahin ang mga cell</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Pagsamahin ang mga napiling cell sa spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>I-set ang alyas</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>I-set ang alyas para sa mga napiling cell</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>I-split ang cell</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>I-split ang nakaraang pinagsamang mga cell sa spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Bold text</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>I-set ang bold text sa napiling mga cell</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Italic na text</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>I-set ang italic text sa napiling mga cell</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>I-underline ang text</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Mga property ng Cell</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Color</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Letra</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Background</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Alignment</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Kaliwa</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Sentro</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Kanan</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Tugatog</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Ibaba</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Style</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Bold</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Italic</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Underline</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Display unit</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Unit string</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alyas para sa cell na ito</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Lahat(*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Import ang file</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Export ang file</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Mga content ng cell</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Ipakita ang spreadsheet</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Magtakda ng kulay sa harapan ng cell(s)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Lumilikha sa kulay ng harapan ng Spreadsheet cell(s)</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Magtakda ng kulay sa likuran ng cell(s)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Lumilikha sa kulay ng harapan ng Spreadsheet cell(s)</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Itim</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Puti</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Pula</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Dark na pagkapula</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Berde</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Dark na berde</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Asul</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Dark na blue</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cyan</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Dark cyan</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Dark magenta</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Dilaw</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Dark na dilaw</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Kulay-abo</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Dark na gray</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Light na kulay abo</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Custom</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Porma</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Contents</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Walang pangalan</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Mag insert ng mga row</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Alisin ang mga row</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Mag insert ng mga column</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Alisin ang mga column</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Mga katangian...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_fil.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fil" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Lumikha ng spreadsheet</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Lumikha ng isang bagong spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>I-align ang bottom</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Ihanay sa ibaba ang mga contents ng mga napiling cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Ihanay sa gitna</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Gitnang hanay ang mga contents ng mga napiling cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Ihanay sa kaliwa</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Kaliwang hanay ang mga contents ng mga napiling cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Ihanay sa kanan</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Right-align ang mga contents ng mga napiling cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Ihanay ang taas</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Top-align ang mga contents ng mga napiing cell</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Patayong center-align</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>I-export ang spreadsheet</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>I-export ang spreadsheet sa CSV file</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>I-import ang spreadsheet</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>I-import ang CSV file sa spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Pagsamahin ang mga cell</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation type="unfinished">Merge selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>I-set ang alyas</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>I-set ang alyas para sa mga napiling cell</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>I-split ang cell</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation type="unfinished">Split previously merged cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Bold text</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation type="unfinished">Set text in selected cells bold</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Italic na text</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation type="unfinished">Set text in selected cells italic</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>I-underline ang text</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Pagsamahin ang mga cell</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>I-split ang cell</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation type="unfinished">Vertically center cells</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation type="unfinished">Set italic text</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation type="unfinished">Set cell properties</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation type="unfinished">Edit cell</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Mag insert ng mga row</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Alisin ang mga row</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Mag insert ng mga column</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation type="unfinished">Set foreground color</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation type="unfinished">Set background color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Mga property ng Cell</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Color</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Letra</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Background</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Alignment</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Kaliwa</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Sentro</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Kanan</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Tugatog</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Ibaba</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Style</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Bold</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Italic</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Underline</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Display unit</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Unit string</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alyas para sa cell na ito</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Lahat(*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Import ang file</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Export ang file</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Ipakita ang spreadsheet</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Magtakda ng kulay sa harapan ng cell(s)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Lumilikha sa kulay ng harapan ng Spreadsheet cell(s)</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Magtakda ng kulay sa likuran ng cell(s)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Lumilikha sa kulay ng harapan ng Spreadsheet cell(s)</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation type="unfinished">Spreadsheet does not support range selection when pasting.
Please select one cell only.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation type="unfinished">Copy &amp; Paste failed</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation type="unfinished">Alias contains invalid characters!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Itim</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Puti</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Pula</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Dark na pagkapula</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Berde</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Dark na berde</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Asul</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Dark na blue</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cyan</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Dark cyan</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Dark magenta</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Dilaw</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Dark na dilaw</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Kulay-abo</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Dark na gray</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Light na kulay abo</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Porma</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation type="unfinished">&amp;Content:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation type="unfinished">&amp;Alias:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Walang pangalan</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Mag insert ng mga row</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Alisin ang mga row</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Mag insert ng mga column</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Alisin ang mga column</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Mga katangian...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Spreadsheet</translation>
    </message>
  </context>
</TS>
